@@ -1,8 +1,7 @@
 require 'spec_helper'
 require 'rainbow'
 
-describe 'Rainbow() wrapper' do
-
+RSpec.describe 'Rainbow() wrapper' do
   before do
     Rainbow.enabled = true
   end
@@ -113,19 +112,19 @@ describe 'Rainbow() wrapper' do
   end
 
   it 'allows chaining' do
-    result = Rainbow('hello').
-      foreground(:red).
-      bright.
-      bold.
-      faint.
-      dark.
-      italic.
-      background('#ff8040').
-      underline.
-      color(:blue).
-      blink.
-      inverse.
-      hide
+    result = Rainbow('hello')
+             .foreground(:red)
+             .bright
+             .bold
+             .faint
+             .dark
+             .italic
+             .background('#ff8040')
+             .underline
+             .color(:blue)
+             .blink
+             .inverse
+             .hide
 
     expect(result).to eq(
       "\e[31m\e[1m\e[1m\e[2m\e[2m\e[3m\e[48;5;215m\e[4m\e[34m\e[5m\e[7m\e[8mhello\e[0m"
@@ -133,28 +132,26 @@ describe 'Rainbow() wrapper' do
   end
 
   context "when Rainbow is disabled" do
-
     before do
       Rainbow.enabled = false
     end
 
     it "allows chaining but doesn't wrap with escape codes" do
-      result = Rainbow('hello').
-        foreground(:red).
-        bright.
-        bold.
-        faint.
-        dark.
-        italic.
-        background('#ff8040').
-        underline.
-        color(:blue).
-        blink.
-        inverse.
-        hide
+      result = Rainbow('hello')
+               .foreground(:red)
+               .bright
+               .bold
+               .faint
+               .dark
+               .italic
+               .background('#ff8040')
+               .underline
+               .color(:blue)
+               .blink
+               .inverse
+               .hide
 
       expect(result).to eq('hello')
     end
   end
-
 end
