@@ -1,8 +1,7 @@
 require 'spec_helper'
 require 'rainbow/ext/string'
 
-describe 'String mixin' do
-
+RSpec.describe 'String mixin' do
   before do
     Rainbow.enabled = true
   end
@@ -31,6 +30,10 @@ describe 'String mixin' do
     expect('hello'.bright).to eq(Rainbow('hello').bright)
   end
 
+  it 'proxies faint to Rainbow().faint' do
+    expect('hello'.faint).to eq(Rainbow('hello').faint)
+  end
+
   it 'proxies italic to Rainbow().italic' do
     expect('hello'.italic).to eq(Rainbow('hello').italic)
   end
@@ -56,25 +59,23 @@ describe 'String mixin' do
   end
 
   context "when Rainbow is disabled" do
-
     before do
       Rainbow.enabled = false
     end
 
     it "allows chaining but doesn't wrap with escape codes" do
-      result = 'hello'.
-        foreground(:red).
-        bright.
-        italic.
-        background('#ff8040').
-        underline.
-        color(:blue).
-        blink.
-        inverse.
-        hide
+      result = 'hello'
+               .foreground(:red)
+               .bright
+               .italic
+               .background('#ff8040')
+               .underline
+               .color(:blue)
+               .blink
+               .inverse
+               .hide
 
       expect(result).to eq('hello')
     end
   end
-
 end
